@@ -5,17 +5,17 @@ def Tacf_pacf_fig(ar, ma, both=False, fig=True, lag=20):
      if fig==True:
         import numpy as np
         import matplotlib.pyplot as plt
-        if lag<31:
+        if lag<21:
            ticks=range(lag+1)
         else:
-           ticks=range(0, lag+1, 5)
+           ticks=range(0, lag+1, 3)
         if both==False:
              plt.vlines(range(lag+1), [0], acf, linewidth=1.5)
              plt.axhline(y=0.0,linewidth=1)
              plt.xticks(ticks=ticks)
              plt.xlabel('Lag')
              plt.ylabel('True ACF')
-             plt.show()
+             #plt.show()
         elif both==True:
             plt.figure()
             plt.subplot(211)
@@ -29,7 +29,7 @@ def Tacf_pacf_fig(ar, ma, both=False, fig=True, lag=20):
             plt.xticks(ticks=ticks)
             plt.xlabel('Lag')
             plt.ylabel('True PACF')
-            plt.show()
+            #plt.show()
      elif fig==False:
            return  acf, pacf 
         
